<?php

namespace Moblyze\Assets\Policies;

use Litepie\User\Contracts\UserPolicy;
use Moblyze\Assets\Models\Assets;

class AssetsPolicy
{

    /**
     * Determine if the given user can view the assets.
     *
     * @param UserPolicy $user
     * @param Assets $assets
     *
     * @return bool
     */
    public function view(UserPolicy $user, Assets $assets)
    {
        if ($user->canDo('assets.assets.view') && $user->isAdmin()) {
            return true;
        }

        return $assets->user_id == user_id() && $assets->user_type == user_type();
    }

    /**
     * Determine if the given user can create a assets.
     *
     * @param UserPolicy $user
     * @param Assets $assets
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('assets.assets.create');
    }

    /**
     * Determine if the given user can update the given assets.
     *
     * @param UserPolicy $user
     * @param Assets $assets
     *
     * @return bool
     */
    public function update(UserPolicy $user, Assets $assets)
    {
        if ($user->canDo('assets.assets.edit') && $user->isAdmin()) {
            return true;
        }

        return $assets->user_id == user_id() && $assets->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given assets.
     *
     * @param UserPolicy $user
     * @param Assets $assets
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Assets $assets)
    {
        return $assets->user_id == user_id() && $assets->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given assets.
     *
     * @param UserPolicy $user
     * @param Assets $assets
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Assets $assets)
    {
        if ($user->canDo('assets.assets.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given assets.
     *
     * @param UserPolicy $user
     * @param Assets $assets
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Assets $assets)
    {
        if ($user->canDo('assets.assets.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
