<?php

namespace Moblyze\Assets\Policies;

use Litepie\User\Contracts\UserPolicy;
use Moblyze\Assets\Models\Engine;

class EnginePolicy
{

    /**
     * Determine if the given user can view the engine.
     *
     * @param UserPolicy $user
     * @param Engine $engine
     *
     * @return bool
     */
    public function view(UserPolicy $user, Engine $engine)
    {
        if ($user->canDo('assets.engine.view') && $user->isAdmin()) {
            return true;
        }

        return $engine->user_id == user_id() && $engine->user_type == user_type();
    }

    /**
     * Determine if the given user can create a engine.
     *
     * @param UserPolicy $user
     * @param Engine $engine
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('assets.engine.create');
    }

    /**
     * Determine if the given user can update the given engine.
     *
     * @param UserPolicy $user
     * @param Engine $engine
     *
     * @return bool
     */
    public function update(UserPolicy $user, Engine $engine)
    {
        if ($user->canDo('assets.engine.edit') && $user->isAdmin()) {
            return true;
        }

        return $engine->user_id == user_id() && $engine->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given engine.
     *
     * @param UserPolicy $user
     * @param Engine $engine
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Engine $engine)
    {
        return $engine->user_id == user_id() && $engine->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given engine.
     *
     * @param UserPolicy $user
     * @param Engine $engine
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Engine $engine)
    {
        if ($user->canDo('assets.engine.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given engine.
     *
     * @param UserPolicy $user
     * @param Engine $engine
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Engine $engine)
    {
        if ($user->canDo('assets.engine.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
