<?php

namespace Moblyze\Assets\Policies;

use Litepie\User\Contracts\UserPolicy;
use Moblyze\Assets\Models\Type;

class TypePolicy
{

    /**
     * Determine if the given user can view the type.
     *
     * @param UserPolicy $user
     * @param Type $type
     *
     * @return bool
     */
    public function view(UserPolicy $user, Type $type)
    {
        if ($user->canDo('assets.type.view') && $user->isAdmin()) {
            return true;
        }

        return $type->user_id == user_id() && $type->user_type == user_type();
    }

    /**
     * Determine if the given user can create a type.
     *
     * @param UserPolicy $user
     * @param Type $type
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('assets.type.create');
    }

    /**
     * Determine if the given user can update the given type.
     *
     * @param UserPolicy $user
     * @param Type $type
     *
     * @return bool
     */
    public function update(UserPolicy $user, Type $type)
    {
        if ($user->canDo('assets.type.edit') && $user->isAdmin()) {
            return true;
        }

        return $type->user_id == user_id() && $type->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given type.
     *
     * @param UserPolicy $user
     * @param Type $type
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Type $type)
    {
        return $type->user_id == user_id() && $type->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given type.
     *
     * @param UserPolicy $user
     * @param Type $type
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Type $type)
    {
        if ($user->canDo('assets.type.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given type.
     *
     * @param UserPolicy $user
     * @param Type $type
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Type $type)
    {
        if ($user->canDo('assets.type.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
