<?php

namespace Moblyze\Assets\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Moblyze\Assets\Models\Assets;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Moblyze\Assets\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/assets/assets/*')) {
            Route::bind('assets', function ($assets) {
                $assetsrepo = $this->app->make('Moblyze\Assets\Interfaces\AssetsRepositoryInterface');
                return $assetsrepo->findorNew($assets);
            });
        }

        if (Request::is('*/assets/engine/*')) {
            Route::bind('engine', function ($engine) {
                $enginerepo = $this->app->make('Moblyze\Assets\Interfaces\EngineRepositoryInterface');
                return $enginerepo->findorNew($engine);
            });
        }

        if (Request::is('*/assets/type/*')) {
            Route::bind('type', function ($type) {
                $typerepo = $this->app->make('Moblyze\Assets\Interfaces\TypeRepositoryInterface');
                return $typerepo->findorNew($type);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
